/*
integrit - file integrity verification system
Copyright (C) 2005 Ed L. Cashin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
/* hexprint.c */
#include	<config.h>
#include	<stdio.h>
#include	"hexprint_p.h"
#ifdef		ELC_FIND_LEAKS
#include	"leakfind.h"
#endif

void hexprint(FILE *out, const unsigned char *buf, size_t n)
{
    while (n--)
      fprintf(out, "%02x", 0xff & *buf++);
}

